@@ -1,16 +1,14 @@
-"""Qwen QwQ Thingking chat models."""
+"""Integration for Qwen QwQ and Qwen3  with thinking chat models."""
 
 from json import JSONDecodeError
-from operator import itemgetter
 from typing import (
     Any,
     AsyncIterator,
-    Callable,
     Dict,
     Iterator,
     List,
+    Literal,
     Optional,
-    Sequence,
     Type,
     TypeVar,
     Union,
@@ -19,23 +17,14 @@ from typing import (
 import json_repair as json
 import openai
 from langchain_core.callbacks import (
+    AsyncCallbackManagerForLLMRun,
     CallbackManagerForLLMRun,
 )
 from langchain_core.language_models import LanguageModelInput
-from langchain_core.messages import (
-    AIMessage,
-    AIMessageChunk,
-    BaseMessage,
-)
-from langchain_core.output_parsers.openai_tools import (
-    JsonOutputKeyToolsParser,
-    PydanticToolsParser,
-)
+from langchain_core.messages import AIMessage, AIMessageChunk, BaseMessage, ToolCall
 from langchain_core.outputs import ChatGeneration, ChatGenerationChunk, ChatResult
-from langchain_core.runnables import Runnable, RunnableMap, RunnablePassthrough
-from langchain_core.tools import BaseTool
+from langchain_core.runnables import Runnable
 from langchain_core.utils import from_env, secret_from_env
-from langchain_core.utils.function_calling import convert_to_openai_tool
 from langchain_core.utils.pydantic import is_basemodel_subclass
 from langchain_openai.chat_models.base import BaseChatOpenAI
 from pydantic import BaseModel, ConfigDict, Field, SecretStr, model_validator
@@ -47,6 +36,9 @@ _BM = TypeVar("_BM", bound=BaseModel)
 _DictOrPydanticClass = Union[Dict[str, Any], Type[_BM], Type]
 _DictOrPydantic = Union[Dict, _BM]
 
+# Store the original __add__ method
+original_add = AIMessageChunk.__add__
+
 
 class ChatQwQ(BaseChatOpenAI):
     """Qwen QwQ Thinking chat model integration to access models hosted in Qwen QwQ Thinking's API.
@@ -149,11 +141,12 @@ class ChatQwQ(BaseChatOpenAI):
     api_key: Optional[SecretStr] = Field(
         default_factory=secret_from_env("DASHSCOPE_API_KEY", default=None)
     )
-    """DeepSeek API key"""
+    """Qwen QwQ Thinking API key"""
     api_base: str = Field(
-        default_factory=from_env("DASHSCOPE_API_BASE", default=DEFAULT_API_BASE)
+        default_factory=from_env("DASHSCOPE_API_BASE", default=DEFAULT_API_BASE),
+        alias="base_url",
     )
-    """DeepSeek API base URL"""
+    """Qwen QwQ Thinking API base URL"""
 
     model_config = ConfigDict(populate_by_name=True)
 
@@ -221,9 +214,9 @@ class ChatQwQ(BaseChatOpenAI):
             if isinstance(model_extra, dict) and (
                 reasoning := model_extra.get("reasoning")
             ):
-                rtn.generations[0].message.additional_kwargs[
-                    "reasoning_content"
-                ] = reasoning
+                rtn.generations[0].message.additional_kwargs["reasoning_content"] = (
+                    reasoning
+                )
 
         return rtn
 
@@ -255,7 +248,7 @@ class ChatQwQ(BaseChatOpenAI):
                             generation_chunk.message.tool_calls.append(
                                 {
                                     "id": tool_call.get("id", ""),
-                                    "type": "function",
+                                    "type": "function",  # type: ignore
                                     "name": tool_call.get("function", {}).get(
                                         "name", ""
                                     ),
@@ -276,11 +269,8 @@ class ChatQwQ(BaseChatOpenAI):
     ) -> Iterator[ChatGenerationChunk]:
         from langchain_core.messages import AIMessageChunk
 
-        # Store the original __add__ method
-        original_add = AIMessageChunk.__add__
-
         # Helper function to check if a tool call is valid
-        def is_valid_tool_call(tc):
+        def is_valid_tool_call(tc: ToolCall) -> bool:
             # Filter out invalid/incomplete tool calls
             if not tc:
                 return False
@@ -301,8 +291,9 @@ class ChatQwQ(BaseChatOpenAI):
             return True
 
         # Create a patched version that ensures tool_calls are preserved
-        def patched_add(self, other):
-            result = original_add(self, other)
+        def patched_add(self: AIMessageChunk, other: AIMessageChunk) -> AIMessageChunk:
+            if not isinstance(result := original_add(self, other), AIMessageChunk):
+                raise ValueError("Result is not an AIMessageChunk")
 
             # Ensure tool_calls are preserved across additions
             if hasattr(self, "tool_calls") and self.tool_calls:
@@ -328,9 +319,10 @@ class ChatQwQ(BaseChatOpenAI):
             return result
 
         # Monkey patch the __add__ method
-        AIMessageChunk.__add__ = patched_add
+        AIMessageChunk.__add__ = patched_add  # type: ignore
 
         try:
+            kwargs["stream_options"] = {"include_usage": True}
             # Original streaming
             for chunk in super()._stream(
                 messages, stop=stop, run_manager=run_manager, **kwargs
@@ -338,7 +330,7 @@ class ChatQwQ(BaseChatOpenAI):
                 yield chunk
         finally:
             # Restore the original method
-            AIMessageChunk.__add__ = original_add
+            AIMessageChunk.__add__ = original_add  # type: ignore
 
     def _generate(
         self,
@@ -396,17 +388,33 @@ class ChatQwQ(BaseChatOpenAI):
 
             last_chunk = chunks[-1]
 
+            # Extract usage info from the last chunk's generation_info
+            generation_info = last_chunk.generation_info or {}
+            # Extract usage metadata from chunk if available
+            if hasattr(last_chunk.message, "usage_metadata"):
+                usage_metadata = last_chunk.message.usage_metadata  # type: ignore
+            else:
+                usage_metadata = {}
+
             return ChatResult(
                 generations=[
                     ChatGeneration(
-                        generation_info=last_chunk.generation_info,
+                        generation_info=generation_info,
                         message=AIMessage(
                             content=content,
                             additional_kwargs={"reasoning_content": reasoning_content},
                             tool_calls=tool_calls,
+                            usage_metadata=usage_metadata,
+                            response_metadata={"model_name": self.model_name},
                         ),
                     )
-                ]
+                ],
+                # Explicitly include usage at the ChatResult level if needed
+                llm_output=(
+                    {"usage": generation_info.get("usage")}
+                    if "usage" in generation_info
+                    else None
+                ),
             )
 
         except JSONDecodeError as e:
@@ -421,7 +429,7 @@ class ChatQwQ(BaseChatOpenAI):
         self,
         messages: List[BaseMessage],
         stop: Optional[List[str]] = None,
-        run_manager: Optional[CallbackManagerForLLMRun] = None,
+        run_manager: Optional[AsyncCallbackManagerForLLMRun] = None,
         **kwargs: Any,
     ) -> ChatResult:
         try:
@@ -476,17 +484,33 @@ class ChatQwQ(BaseChatOpenAI):
 
             last_chunk = chunks[-1]
 
+            # Extract usage info from the last chunk's generation_info
+            generation_info = last_chunk.generation_info or {}
+            # Extract usage metadata from chunk if available
+            if hasattr(last_chunk.message, "usage_metadata"):
+                usage_metadata = last_chunk.message.usage_metadata  # type: ignore
+            else:
+                usage_metadata = {}
+
             return ChatResult(
                 generations=[
                     ChatGeneration(
-                        generation_info=last_chunk.generation_info,
+                        generation_info=generation_info,
                         message=AIMessage(
                             content=content,
                             additional_kwargs={"reasoning_content": reasoning_content},
                             tool_calls=tool_calls,
+                            usage_metadata=usage_metadata,
+                            response_metadata={"model_name": self.model_name},
                         ),
                     )
-                ]
+                ],
+                # Explicitly include usage at the ChatResult level if needed
+                llm_output=(
+                    {"usage": generation_info.get("usage")}
+                    if "usage" in generation_info
+                    else None
+                ),
             )
 
         except JSONDecodeError as e:
@@ -501,16 +525,13 @@ class ChatQwQ(BaseChatOpenAI):
         self,
         messages: List[BaseMessage],
         stop: Optional[List[str]] = None,
-        run_manager: Optional[CallbackManagerForLLMRun] = None,
+        run_manager: Optional[AsyncCallbackManagerForLLMRun] = None,
         **kwargs: Any,
     ) -> AsyncIterator[ChatGenerationChunk]:
         from langchain_core.messages import AIMessageChunk
 
-        # Store the original __add__ method
-        original_add = AIMessageChunk.__add__
-
         # Helper function to check if a tool call is valid
-        def is_valid_tool_call(tc):
+        def is_valid_tool_call(tc: ToolCall) -> bool:
             # Filter out invalid/incomplete tool calls
             if not tc:
                 return False
@@ -531,8 +552,9 @@ class ChatQwQ(BaseChatOpenAI):
             return True
 
         # Create a patched version that ensures tool_calls are preserved
-        def patched_add(self, other):
-            result = original_add(self, other)
+        def patched_add(self: AIMessageChunk, other: AIMessageChunk) -> AIMessageChunk:
+            if not isinstance(result := original_add(self, other), AIMessageChunk):
+                raise ValueError("Result is not an AIMessageChunk")
 
             # Ensure tool_calls are preserved across additions
             if hasattr(self, "tool_calls") and self.tool_calls:
@@ -558,9 +580,10 @@ class ChatQwQ(BaseChatOpenAI):
             return result
 
         # Monkey patch the __add__ method
-        AIMessageChunk.__add__ = patched_add
+        AIMessageChunk.__add__ = patched_add  # type: ignore
 
         try:
+            kwargs["stream_options"] = {"include_usage": True}
             # Original async streaming
             async for chunk in super()._astream(
                 messages, stop=stop, run_manager=run_manager, **kwargs
@@ -568,86 +591,129 @@ class ChatQwQ(BaseChatOpenAI):
                 yield chunk
         finally:
             # Restore the original method
-            AIMessageChunk.__add__ = original_add
+            AIMessageChunk.__add__ = original_add  # type: ignore
 
     def with_structured_output(
         self,
-        schema: Union[Dict, Type[BaseModel]],
+        schema: Optional[_DictOrPydanticClass] = None,
         *,
+        method: Literal["function_calling", "json_mode", "json_schema"] = "json_mode",
         include_raw: bool = False,
-        method: str = "function_calling",
         strict: Optional[bool] = None,
         **kwargs: Any,
-    ) -> Runnable[LanguageModelInput, Union[Dict, BaseModel]]:
-        """Create a version of this chat model that returns outputs formatted according to the given schema.
+    ) -> Runnable[LanguageModelInput, _DictOrPydantic]:
+        (
+            """Create a version of this chat model that returns outputs formatted """
+            """according to the given schema.
 
         Args:
-            schema: The schema to use for formatting the output. Can be a dictionary or a Pydantic model.
+            schema: The schema to use for formatting the output. Can be a dictionary"""
+            """or a Pydantic model.
             include_raw: Whether to include the raw model output in the output.
-            method: The method to use for formatting the output. Should be "function_calling" for OpenAI compatibility.
-            strict: Whether to enforce strict validation of the output against the schema. If not provided, will default to True.
+            method: The method to use for formatting the output.
+            strict: Whether to enforce strict validation of the output against """
+            """the schema. If not provided, will default to True.
             **kwargs: Additional keyword arguments to pass to the model.
 
         Returns:
             A runnable that returns outputs formatted according to the given schema.
         """
+        )
         import json
         import re
-        from copy import deepcopy
-        from operator import itemgetter
-        from langchain_core.runnables import (
-            RunnableLambda,
-            RunnableMap,
-            RunnablePassthrough,
-        )
-        from langchain_core.output_parsers import BaseOutputParser
-        from langchain_core.messages import SystemMessage, HumanMessage
-        from langchain_core.utils.function_calling import convert_to_openai_tool
 
-        # Set default for strict
+        from langchain_core.messages import HumanMessage, SystemMessage
+        from langchain_core.output_parsers import BaseOutputParser
+        from langchain_core.runnables import RunnableLambda
+        from langchain_core.utils.function_calling import convert_to_json_schema
+
         if strict is None:
             strict = True
 
-        # Extract schema information
-        is_pydantic_schema = is_basemodel_subclass(schema)
+        if schema is None:
+            if method != "json_mode":
+                raise ValueError(
+                    "schema must be provided when method is not 'json_mode'"
+                )
+            schema_dict = {}
+            schema_name = "CustomOutput"
+            output_cls = None
 
-        # Create the schema dict, name, and output class using convert_to_json_schema
-        from langchain_core.utils.function_calling import convert_to_json_schema
-
-        try:
-            schema_dict = convert_to_json_schema(schema)
-            if is_pydantic_schema:
-                schema_name = schema.__name__
-                output_cls = schema
-            elif isinstance(schema, dict):
-                schema_name = schema.get("title", "CustomOutput")
-                output_cls = None
-            else:
-                schema_name = getattr(schema, "__name__", "CustomOutput")
-                output_cls = None
-        except Exception as e:
-            # Fallback for cases where convert_to_json_schema fails
-            if is_pydantic_schema:
-                if hasattr(schema, "model_json_schema"):
-                    schema_dict = schema.model_json_schema()  # Pydantic v2
-                elif hasattr(schema, "schema"):
-                    schema_dict = schema.schema()  # Pydantic v1
+        else:
+            # Extract schema information using convert_to_json_schema
+            try:
+                schema_dict = convert_to_json_schema(schema)
+                if isinstance(schema, type) and is_basemodel_subclass(schema):
+                    schema_name = schema.__name__
+                    output_cls = schema
+                elif isinstance(schema, dict):
+                    schema_name = schema.get("title", "CustomOutput")
+                    output_cls = None
                 else:
-                    raise ValueError(f"Unsupported Pydantic model: {schema}")
-                schema_name = schema.__name__
-                output_cls = schema
-            elif isinstance(schema, dict):
-                schema_dict = schema
-                schema_name = schema_dict.get("title", "CustomOutput")
-                output_cls = None
-            else:
-                raise ValueError(f"Unsupported schema type: {type(schema)}: {str(e)}")
+                    schema_name = getattr(schema, "__name__", "CustomOutput")
+                    output_cls = None
+            except Exception:
+                # Fallback for cases where convert_to_json_schema fails
+                if isinstance(schema, type) and is_basemodel_subclass(schema):
+                    if hasattr(schema, "model_json_schema"):
+                        schema_dict = schema.model_json_schema()  # Pydantic v2
+                    elif hasattr(schema, "schema"):
+                        schema_dict = schema.schema()  # Pydantic v1
+                    else:
+                        raise ValueError(f"Unsupported Pydantic model: {schema}")
+                    schema_name = schema.__name__
+                    output_cls = schema
+                elif isinstance(schema, dict):
+                    schema_dict = schema
+                    schema_name = schema_dict.get("title", "CustomOutput")
+                    output_cls = None
+                else:
+                    raise ValueError(f"Unsupported schema type: {type(schema)}")
+
+            if method == "function_calling":
+                from operator import itemgetter
+
+                from langchain_core.output_parsers import (
+                    JsonOutputKeyToolsParser,
+                    PydanticToolsParser,
+                )
+                from langchain_core.output_parsers.base import OutputParserLike
+                from langchain_core.runnables import RunnableMap, RunnablePassthrough
+                from langchain_core.utils.function_calling import convert_to_openai_tool
+
+                is_pydantic_schema = isinstance(schema, type) and is_basemodel_subclass(
+                    schema
+                )
+                llm = self.bind_tools([schema])
+                if is_pydantic_schema:
+                    output_parser: OutputParserLike = PydanticToolsParser(
+                        tools=[schema],  # type: ignore[list-item]
+                        first_tool_only=True,
+                    )
+                else:
+                    key_name = convert_to_openai_tool(schema)["function"]["name"]
+                    output_parser = JsonOutputKeyToolsParser(
+                        key_name=key_name, first_tool_only=True
+                    )
+
+                if include_raw:
+                    parser_assign = RunnablePassthrough.assign(
+                        parsed=itemgetter("raw") | output_parser,
+                        parsing_error=lambda _: None,
+                    )
+                    parser_none = RunnablePassthrough.assign(parsed=lambda _: None)
+                    parser_with_fallback = parser_assign.with_fallbacks(
+                        [parser_none], exception_key="parsing_error"
+                    )
+                    return RunnableMap(raw=llm) | parser_with_fallback
+                else:
+                    return llm | output_parser
 
         # Create a custom output parser
-        class StructuredOutputParser(BaseOutputParser):
+        class StructuredOutputParser(BaseOutputParser[Any]):
             """Parser for structured output from QwQ."""
 
-            def parse(self, text):
+            def parse(self, text: str) -> Any:
                 """Parse the output and convert to the target format."""
                 try:
                     # Try to parse as JSON
@@ -677,7 +743,7 @@ class ChatQwQ(BaseChatOpenAI):
                         elif hasattr(output_cls, "parse_obj"):
                             return output_cls.parse_obj(parsed)
                         else:
-                            raise ValueError(f"Unsupported Pydantic validation method")
+                            raise ValueError("Unsupported Pydantic validation method")
                     return parsed
                 except Exception as e:
                     if strict:
@@ -685,7 +751,9 @@ class ChatQwQ(BaseChatOpenAI):
                     return text
 
         # Create system prompt for JSON output
-        system_template = """You are a helpful assistant that always responds with JSON that matches this schema:
+        system_template = (
+            """You are a helpful assistant that always responds with"""
+            """JSON that matches this schema:
     ```json
     {schema}
     ```
@@ -702,13 +770,14 @@ class ChatQwQ(BaseChatOpenAI):
     Example of a good response format:
     {{"key1": "value1", "key2": 42, "key3": false}}
     """
+        )
 
         # Format the schema for the prompt
         formatted_schema = json.dumps(schema_dict, indent=2)
         system_content = system_template.format(schema=formatted_schema)
 
         # Create a function to prepare messages with the system prompt
-        def prepare_messages(input_value):
+        def prepare_messages(input_value: Any) -> List[BaseMessage]:
             """Prepare messages with system prompt for structured output."""
             if isinstance(input_value, str):
                 return [
@@ -732,7 +801,7 @@ class ChatQwQ(BaseChatOpenAI):
                     return messages
                 else:
                     # Add system message at the beginning
-                    return [SystemMessage(content=system_content)] + input_value
+                    return [SystemMessage(content=system_content)] + input_value  # type: ignore
             else:
                 # Convert to string and use as human message
                 return [
@@ -741,7 +810,6 @@ class ChatQwQ(BaseChatOpenAI):
                 ]
 
         # Create a modified version of the model with structured output format
-        # This is the key part for callbacks - we use bind() to attach the metadata
         structured_model = self.bind(
             ls_structured_output_format={
                 "schema": schema_dict,
@@ -757,20 +825,171 @@ class ChatQwQ(BaseChatOpenAI):
         # Build the chain
         if include_raw:
             # Include raw output in the result
-            chain = (
-                RunnableMap(
-                    {"raw": lambda x: structured_model.invoke(prepare_messages(x))}
-                )
-                .assign(parsed=lambda x: output_parser.parse(x["raw"].content))
-                .with_fallbacks(
-                    [RunnableMap({"raw": itemgetter("raw"), "parsed": lambda x: None})],
-                    exception_key="parsing_error",
-                )
-            )
+            def process_with_raw(x: Any) -> Dict[str, Any]:
+                raw_output = structured_model.invoke(prepare_messages(x))
+                try:
+                    if isinstance(raw_output.content, str):
+                        parsed = output_parser.parse(raw_output.content)
+                    else:
+                        parsed = raw_output.content
+                    return {"raw": raw_output, "parsed": parsed, "parsing_error": None}
+                except Exception as e:
+                    return {"raw": raw_output, "parsed": None, "parsing_error": e}
+
+            async def aprocess_with_raw(x: Any) -> Dict[str, Any]:
+                raw_output = await structured_model.ainvoke(prepare_messages(x))
+                try:
+                    if isinstance(raw_output.content, str):
+                        parsed = output_parser.parse(raw_output.content)
+                    else:
+                        parsed = raw_output.content
+                    return {"raw": raw_output, "parsed": parsed, "parsing_error": None}
+                except Exception as e:
+                    return {"raw": raw_output, "parsed": None, "parsing_error": e}
+
+            chain = RunnableLambda(process_with_raw, afunc=aprocess_with_raw)
         else:
             # Only return parsed output
-            chain = RunnableLambda(
-                lambda x: structured_model.invoke(prepare_messages(x))
-            ) | RunnableLambda(lambda x: output_parser.parse(x.content))
+            def process_without_raw(x: Any) -> Any:
+                raw_output = structured_model.invoke(prepare_messages(x))
+                if isinstance(raw_output.content, str):
+                    return output_parser.parse(raw_output.content)
+                else:
+                    return raw_output.content
+
+            async def aprocess_without_raw(x: Any) -> Any:
+                raw_output = await structured_model.ainvoke(prepare_messages(x))
+                if isinstance(raw_output.content, str):
+                    return output_parser.parse(raw_output.content)
+                else:
+                    return raw_output.content
+
+            chain = RunnableLambda(process_without_raw, afunc=aprocess_without_raw)
 
         return chain
+
+
+class ChatQwen(ChatQwQ):
+    """Qwen Qwen3 Thinking chat model integration to access models hosted in Qwen Qwen3's API.
+
+    Setup:
+        Install ``langchain-qwq`` and set environment variable ``DASHSCOPE_API_KEY``.
+
+        .. code-block:: bash
+
+            pip install -U langchain-qwq
+            export DASHSCOPE_API_KEY="your-api-key"
+
+    Key init args — completion params:
+        model: str
+            Name of Qwen Qwen3 model to use, e.g. "qwen3-32b".
+        temperature: float
+            Sampling temperature.
+        max_tokens: Optional[int]
+            Max number of tokens to generate.
+
+    Key init args — client params:
+        timeout: Optional[float]
+            Timeout for requests.
+        max_retries: int
+            Max number of retries.
+        api_key: Optional[str]
+            Qwen QwQ Thingking API key. If not passed in will be read from env var DASHSCOPE_API_KEY.
+
+    See full list of supported init args and their descriptions in the params section.
+
+    Instantiate:
+        .. code-block:: python
+
+            from langchain_qwq import ChatQwen
+
+            llm = ChatQwen(
+                model="...",
+                temperature=0,
+                max_tokens=None,
+                timeout=None,
+                max_retries=2,
+                # api_key="...",
+                # other params...
+            )
+
+    Invoke:
+        .. code-block:: python
+
+            messages = [
+                ("system", "You are a helpful translator. Translate the user sentence to French."),
+                ("human", "I love programming."),
+            ]
+            llm.invoke(messages)
+
+    Stream:
+        .. code-block:: python
+
+            for chunk in llm.stream(messages):
+                print(chunk.text(), end="")
+
+        .. code-block:: python
+
+            stream = llm.stream(messages)
+            full = next(stream)
+            for chunk in stream:
+                full += chunk
+            full
+
+    Async:
+        .. code-block:: python
+
+            # Basic async invocation
+            result = await llm.ainvoke(messages)
+
+            # Access content and reasoning
+            content = result.content
+            reasoning = result.additional_kwargs.get("reasoning_content", "")
+
+            # Stream response chunks
+            async for chunk in await llm.astream(messages):
+                print(chunk.content, end="")
+                # Access reasoning in each chunk
+                reasoning_chunk = chunk.additional_kwargs.get("reasoning_content", "")
+
+            # Process tool calls in completion
+            if hasattr(result, "tool_calls") and result.tool_calls:
+                for tool_call in result.tool_calls:
+                    tool_id = tool_call.get("id")
+                    tool_name = tool_call.get("name")
+                    tool_args = tool_call.get("args")
+                    # Process tool call...
+
+            # Batch processing of multiple message sets
+            results = await llm.abatch([messages1, messages2])
+
+    """  # noqa: E501
+
+    model_name: str = Field(default="qwen3-32b", alias="model")
+    """The name of the model"""
+
+    enable_thinking: Optional[bool] = Field(default=None)
+    """Whether to enable thinking"""
+
+    thinking_budget: Optional[int] = Field(default=None)
+    """Thinking budget"""
+
+    @property
+    def _llm_type(self) -> str:
+        """Return type of chat model."""
+        return "chat-qwen"
+
+    @property
+    def _default_params(self) -> Dict[str, Any]:
+        """Get the default parameters for calling ChatQwen API."""
+        params = super()._default_params
+        if self.enable_thinking is not None:
+            if "extra_body" not in params:
+                params["extra_body"] = {}
+            params["extra_body"]["enable_thinking"] = self.enable_thinking
+        if self.thinking_budget is not None:
+            if "extra_body" not in params:
+                params["extra_body"] = {}
+            params["extra_body"]["thinking_budget"] = self.thinking_budget
+
+        return params
